[gnome-settings-daemon] media-keys: Make the OSD window smaller



commit fbf3c5aa366ef7212f209e123d4aae315a1a2a8e
Author: Cosimo Cecchi <cosimoc gnome org>
Date:   Fri Jan 11 12:39:42 2013 -0500

    media-keys: Make the OSD window smaller
    
    Matches the mockups better; to compensate, make the icon take up more
    space inside.
    
    https://bugzilla.gnome.org/show_bug.cgi?id=652321

 plugins/media-keys/gsd-osd-window.c |    6 +++---
 1 files changed, 3 insertions(+), 3 deletions(-)
---
diff --git a/plugins/media-keys/gsd-osd-window.c b/plugins/media-keys/gsd-osd-window.c
index 90ac5e7..f382a7b 100644
--- a/plugins/media-keys/gsd-osd-window.c
+++ b/plugins/media-keys/gsd-osd-window.c
@@ -40,7 +40,7 @@
 #include "gsd-osd-window.h"
 #include "gsd-osd-window-private.h"
 
-#define ICON_SCALE 0.50           /* size of the icon compared to the whole OSD */
+#define ICON_SCALE 0.55           /* size of the icon compared to the whole OSD */
 #define FG_ALPHA 1.0              /* Alpha value to be used for foreground objects drawn in an OSD window */
 
 #define GSD_OSD_WINDOW_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GSD_TYPE_OSD_WINDOW, GsdOsdWindowPrivate))
@@ -940,11 +940,11 @@ gsd_osd_window_init (GsdOsdWindow *window)
         gtk_window_set_decorated (GTK_WINDOW (window), FALSE);
         gtk_widget_set_app_paintable (GTK_WIDGET (window), TRUE);
 
         /* assume 130x130 on a 640x480 display and scale from there */
         scalew = monitor.width / 640.0;
         scaleh = monitor.height / 480.0;
         scale = MIN (scalew, scaleh);
-        size = 130 * MAX (1, scale);
+        size = 110 * MAX (1, scale);
         gtk_window_set_default_size (GTK_WINDOW (window), size, size);
 
         window->priv->fade_out_alpha = 1.0;
@@ -940,11 +940,11 @@ gsd_osd_window_init (GsdOsdWindow *window)
         gtk_widget_set_app_paintable (GTK_WIDGET (window), TRUE);
 
-        /* assume 130x130 on a 640x480 display and scale from there */
+        /* assume 110x110 on a 640x480 display and scale from there */
         scalew = monitor.width / 640.0;
         scaleh = monitor.height / 480.0;



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]